@@ -4,9 +4,10 @@ package Dist::Zilla::Plugin::RPM;
 use Moose;
 use Moose::Autobox;
 use Moose::Util::TypeConstraints;
+use Path::Tiny;
 use namespace::autoclean;
 
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 with 'Dist::Zilla::Role::Releaser',
      'Dist::Zilla::Role::FilePruner';
@@ -229,7 +230,7 @@ sub mk_spec {
     my($self,$archive) = @_;
     my $t = Text::Template->new(
         TYPE       => 'FILE',
-        SOURCE     => $self->zilla->root->file($self->spec_file),
+        SOURCE     => path($self->zilla->root)->child($self->spec_file),
         DELIMITERS => [ '<%', '%>' ],
     ) || $self->log_fatal($Text::Template::ERROR);
     return $t->fill_in(
@@ -257,7 +258,7 @@ Dist::Zilla::Plugin::RPM - Build an RPM from your Dist::Zilla release
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
@@ -382,11 +383,11 @@ L<Dist::Zilla|Dist::Zilla>
 
 =head1 AUTHOR
 
-Vincent Lequertier <sky@riseup.net>
+Vincent Lequertier <vi.le@autistici.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by vincent Lequertier, Stephen Clouse.
+This software is copyright (c) 2017 by vincent Lequertier, Stephen Clouse.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
